from io import open
from setuptools import setup, find_packages

setup(name='opigpiogalluss',
      version='0.7',
      author='Gallus',
      author_email='bkmz_repvby@mail.ru',
      description='opigpiogalluss',
      packages=['opigpiogalluss']
      )
